import os, csv
from WaniKaniTools.dir import DATABASE


def chars2ids(chars):
    with open(os.path.join(DATABASE, 'id.txt')) as id_file:
        id_table = csv.reader(id_file, delimiter='\t')
        for row in id_table:
            if row[2] in chars:
                yield row[0]



import os
import inspect

ROOT = os.path.dirname(os.path.abspath(inspect.getframeinfo(inspect.currentframe()).filename))
DATABASE = os.path.join(ROOT, 'database')

if __name__ == '__main__':
    print(ROOT)
    print(DATABASE)



from setuptools import setup

from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='WaniKaniTools',
    version='0.2.2',
    description='Working with WaniKani API, login, and Community.',
    long_description=long_description,
    url='https://github.com/patarapolw/WaniKaniTools',
    author='Pacharapol Withayasakpunt',
    author_email='patarapolw@gmail.com',
    keywords='WaniKani',
    packages=['WaniKaniTools'],
    python_requires='>=2.7',
    install_requires=['requests', 'bs4', 'selenium'],
)
